@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.4.2.  */
+/* A Bison parser, made by GNU Bison 2.5.90.  */
 
 /* Skeleton implementation for Bison LALR(1) parsers in C++
    
-      Copyright (C) 2002-2010 Free Software Foundation, Inc.
+      Copyright (C) 2002-2012 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,8 +34,8 @@
 /* First part of user declarations.  */
 
 
-/* Line 310 of lalr1.cc  */
-#line 39 "./calc++-parser.cc"
+/* Line 278 of lalr1.cc  */
+#line 39 "../../../../examples/calc++/calc++-parser.cc"
 
 
 #include "calc++-parser.hh"
@@ -43,19 +43,28 @@
 /* User implementation prologue.  */
 
 
-/* Line 316 of lalr1.cc  */
-#line 48 "./calc++-parser.cc"
+/* Line 284 of lalr1.cc  */
+#line 48 "../../../../examples/calc++/calc++-parser.cc"
 /* Unqualified %code blocks.  */
 
-/* Line 317 of lalr1.cc  */
-#line 8494 "../../doc/bison.texinfo"
+/* Line 285 of lalr1.cc  */
+#line 9707 "../../doc/bison.texi"
 
 # include "calc++-driver.hh"
 
 
 
-/* Line 317 of lalr1.cc  */
-#line 59 "./calc++-parser.cc"
+/* Line 285 of lalr1.cc  */
+#line 59 "../../../../examples/calc++/calc++-parser.cc"
+
+
+# ifndef YY_NULL
+#  if defined __cplusplus && 201103L <= __cplusplus
+#   define YY_NULL nullptr
+#  else
+#   define YY_NULL 0
+#  endif
+# endif
 
 #ifndef YY_
 # if defined YYENABLE_NLS && YYENABLE_NLS
@@ -69,6 +78,27 @@
 # endif
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+# ifndef YYLLOC_DEFAULT
+#  define YYLLOC_DEFAULT(Current, Rhs, N)                               \
+    do                                                                  \
+      if (N)                                                            \
+        {                                                               \
+          (Current).begin  = YYRHSLOC (Rhs, 1).begin;                   \
+          (Current).end    = YYRHSLOC (Rhs, N).end;                     \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).begin = (Current).end = YYRHSLOC (Rhs, 0).end;      \
+        }                                                               \
+    while (/*CONSTCOND*/ false)
+# endif
+
+
 /* Suppress unused-variable warnings by "using" E.  */
 #define YYUSE(e) ((void) (e))
 
@@ -120,9 +150,8 @@ do {					\
 
 namespace yy {
 
-/* Line 379 of lalr1.cc  */
-#line 125 "./calc++-parser.cc"
-#if YYERROR_VERBOSE
+/* Line 352 of lalr1.cc  */
+#line 155 "../../../../examples/calc++/calc++-parser.cc"
 
   /* Return YYSTR after stripping away unnecessary quotes and
      backslashes, so that it's suitable for yyerror.  The heuristic is
@@ -161,7 +190,6 @@ namespace yy {
     return yystr;
   }
 
-#endif
 
   /// Build a parser object.
   calcxx_parser::calcxx_parser (calcxx_driver& driver_yyarg)
@@ -189,34 +217,37 @@ namespace yy {
   {
     YYUSE (yylocationp);
     YYUSE (yyvaluep);
+    std::ostream& yyo = debug_stream ();
+    std::ostream& yyoutput = yyo;
+    YYUSE (yyoutput);
     switch (yytype)
       {
         case 4: /* "\"identifier\"" */
 
-/* Line 448 of lalr1.cc  */
-#line 8523 "../../doc/bison.texinfo"
-	{ debug_stream () << *(yyvaluep->sval); };
+/* Line 422 of lalr1.cc  */
+#line 9736 "../../doc/bison.texi"
+	{ yyoutput << *(yyvaluep->sval); };
 
-/* Line 448 of lalr1.cc  */
-#line 202 "./calc++-parser.cc"
+/* Line 422 of lalr1.cc  */
+#line 233 "../../../../examples/calc++/calc++-parser.cc"
 	break;
       case 5: /* "\"number\"" */
 
-/* Line 448 of lalr1.cc  */
-#line 8526 "../../doc/bison.texinfo"
-	{ debug_stream () << (yyvaluep->ival); };
+/* Line 422 of lalr1.cc  */
+#line 9739 "../../doc/bison.texi"
+	{ yyoutput << (yyvaluep->ival); };
 
-/* Line 448 of lalr1.cc  */
-#line 211 "./calc++-parser.cc"
+/* Line 422 of lalr1.cc  */
+#line 242 "../../../../examples/calc++/calc++-parser.cc"
 	break;
       case 14: /* "exp" */
 
-/* Line 448 of lalr1.cc  */
-#line 8526 "../../doc/bison.texinfo"
-	{ debug_stream () << (yyvaluep->ival); };
+/* Line 422 of lalr1.cc  */
+#line 9739 "../../doc/bison.texi"
+	{ yyoutput << (yyvaluep->ival); };
 
-/* Line 448 of lalr1.cc  */
-#line 220 "./calc++-parser.cc"
+/* Line 422 of lalr1.cc  */
+#line 251 "../../../../examples/calc++/calc++-parser.cc"
 	break;
        default:
 	  break;
@@ -250,12 +281,12 @@ namespace yy {
       {
         case 4: /* "\"identifier\"" */
 
-/* Line 479 of lalr1.cc  */
-#line 8524 "../../doc/bison.texinfo"
+/* Line 453 of lalr1.cc  */
+#line 9737 "../../doc/bison.texi"
 	{ delete (yyvaluep->sval); };
 
-/* Line 479 of lalr1.cc  */
-#line 259 "./calc++-parser.cc"
+/* Line 453 of lalr1.cc  */
+#line 290 "../../../../examples/calc++/calc++-parser.cc"
 	break;
 
 	default:
@@ -298,6 +329,18 @@ namespace yy {
   }
 #endif
 
+  inline bool
+  calcxx_parser::yy_pact_value_is_default_ (int yyvalue)
+  {
+    return yyvalue == yypact_ninf_;
+  }
+
+  inline bool
+  calcxx_parser::yy_table_value_is_error_ (int yyvalue)
+  {
+    return yyvalue == yytable_ninf_;
+  }
+
   int
   calcxx_parser::parse ()
   {
@@ -319,7 +362,7 @@ namespace yy {
     /// Location of the lookahead.
     location_type yylloc;
     /// The locations where the error started and ended.
-    location_type yyerror_range[2];
+    location_type yyerror_range[3];
 
     /// $$.
     semantic_type yyval;
@@ -333,15 +376,15 @@ namespace yy {
 
     /* User initialization code.  */
     
-/* Line 552 of lalr1.cc  */
-#line 8457 "../../doc/bison.texinfo"
+/* Line 538 of lalr1.cc  */
+#line 9669 "../../doc/bison.texi"
 {
   // Initialize the initial location.
   yylloc.begin.filename = yylloc.end.filename = &driver.file;
 }
 
-/* Line 552 of lalr1.cc  */
-#line 345 "./calc++-parser.cc"
+/* Line 538 of lalr1.cc  */
+#line 388 "../../../../examples/calc++/calc++-parser.cc"
 
     /* Initialize the stacks.  The initial state will be pushed in
        yynewstate, since the latter expects the semantical and the
@@ -369,7 +412,7 @@ namespace yy {
 
     /* Try to take a decision without lookahead.  */
     yyn = yypact_[yystate];
-    if (yyn == yypact_ninf_)
+    if (yy_pact_value_is_default_ (yyn))
       goto yydefault;
 
     /* Read a lookahead token.  */
@@ -402,8 +445,8 @@ namespace yy {
     yyn = yytable_[yyn];
     if (yyn <= 0)
       {
-	if (yyn == 0 || yyn == yytable_ninf_)
-	goto yyerrlab;
+	if (yy_table_value_is_error_ (yyn))
+	  goto yyerrlab;
 	yyn = -yyn;
 	goto yyreduce;
       }
@@ -459,81 +502,92 @@ namespace yy {
       {
 	  case 2:
 
-/* Line 677 of lalr1.cc  */
-#line 8536 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9749 "../../doc/bison.texi"
     { driver.result = (yysemantic_stack_[(2) - (2)].ival); }
     break;
 
   case 3:
 
-/* Line 677 of lalr1.cc  */
-#line 8538 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9752 "../../doc/bison.texi"
     {}
     break;
 
   case 4:
 
-/* Line 677 of lalr1.cc  */
-#line 8539 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9753 "../../doc/bison.texi"
     {}
     break;
 
   case 5:
 
-/* Line 677 of lalr1.cc  */
-#line 8543 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9757 "../../doc/bison.texi"
     { driver.variables[*(yysemantic_stack_[(3) - (1)].sval)] = (yysemantic_stack_[(3) - (3)].ival); delete (yysemantic_stack_[(3) - (1)].sval); }
     break;
 
   case 6:
 
-/* Line 677 of lalr1.cc  */
-#line 8547 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9761 "../../doc/bison.texi"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) + (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 7:
 
-/* Line 677 of lalr1.cc  */
-#line 8548 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9762 "../../doc/bison.texi"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) - (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 8:
 
-/* Line 677 of lalr1.cc  */
-#line 8549 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9763 "../../doc/bison.texi"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) * (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 9:
 
-/* Line 677 of lalr1.cc  */
-#line 8550 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9764 "../../doc/bison.texi"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) / (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 10:
 
-/* Line 677 of lalr1.cc  */
-#line 8551 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9765 "../../doc/bison.texi"
     { (yyval.ival) = driver.variables[*(yysemantic_stack_[(1) - (1)].sval)]; delete (yysemantic_stack_[(1) - (1)].sval); }
     break;
 
   case 11:
 
-/* Line 677 of lalr1.cc  */
-#line 8552 "../../doc/bison.texinfo"
+/* Line 663 of lalr1.cc  */
+#line 9766 "../../doc/bison.texi"
     { (yyval.ival) = (yysemantic_stack_[(1) - (1)].ival); }
     break;
 
 
 
-/* Line 677 of lalr1.cc  */
-#line 534 "./calc++-parser.cc"
+/* Line 663 of lalr1.cc  */
+#line 577 "../../../../examples/calc++/calc++-parser.cc"
 	default:
           break;
       }
+    /* User semantic actions sometimes alter yychar, and that requires
+       that yytoken be updated with the new translation.  We take the
+       approach of translating immediately before every use of yytoken.
+       One alternative is translating here after every semantic action,
+       but that translation would be missed if the semantic action
+       invokes YYABORT, YYACCEPT, or YYERROR immediately after altering
+       yychar.  In the case of YYABORT or YYACCEPT, an incorrect
+       destructor might then be invoked immediately.  In the case of
+       YYERROR, subsequent parser actions might lead to an incorrect
+       destructor call or verbose syntax error message before the
+       lookahead is translated.  */
     YY_SYMBOL_PRINT ("-> $$ =", yyr1_[yyn], &yyval, &yyloc);
 
     yypop_ (yylen);
@@ -557,14 +611,20 @@ namespace yy {
   | yyerrlab -- here on detecting error |
   `------------------------------------*/
   yyerrlab:
+    /* Make sure we have latest lookahead translation.  See comments at
+       user semantic actions for why this is necessary.  */
+    yytoken = yytranslate_ (yychar);
+
     /* If not already recovering from an error, report this error.  */
     if (!yyerrstatus_)
       {
 	++yynerrs_;
+	if (yychar == yyempty_)
+	  yytoken = yyempty_;
 	error (yylloc, yysyntax_error_ (yystate, yytoken));
       }
 
-    yyerror_range[0] = yylloc;
+    yyerror_range[1] = yylloc;
     if (yyerrstatus_ == 3)
       {
 	/* If just tried and failed to reuse lookahead token after an
@@ -599,7 +659,7 @@ namespace yy {
     if (false)
       goto yyerrorlab;
 
-    yyerror_range[0] = yylocation_stack_[yylen - 1];
+    yyerror_range[1] = yylocation_stack_[yylen - 1];
     /* Do not reclaim the symbols of the rule which action triggered
        this YYERROR.  */
     yypop_ (yylen);
@@ -616,7 +676,7 @@ namespace yy {
     for (;;)
       {
 	yyn = yypact_[yystate];
-	if (yyn != yypact_ninf_)
+	if (!yy_pact_value_is_default_ (yyn))
 	{
 	  yyn += yyterror_;
 	  if (0 <= yyn && yyn <= yylast_ && yycheck_[yyn] == yyterror_)
@@ -631,7 +691,7 @@ namespace yy {
 	if (yystate_stack_.height () == 1)
 	YYABORT;
 
-	yyerror_range[0] = yylocation_stack_[0];
+	yyerror_range[1] = yylocation_stack_[0];
 	yydestruct_ ("Error: popping",
 		     yystos_[yystate],
 		     &yysemantic_stack_[0], &yylocation_stack_[0]);
@@ -640,10 +700,10 @@ namespace yy {
 	YY_STACK_PRINT ();
       }
 
-    yyerror_range[1] = yylloc;
+    yyerror_range[2] = yylloc;
     // Using YYLLOC is tempting, but would change the location of
     // the lookahead.  YYLOC is available though.
-    YYLLOC_DEFAULT (yyloc, (yyerror_range - 1), 2);
+    YYLLOC_DEFAULT (yyloc, yyerror_range, 2);
     yysemantic_stack_.push (yylval);
     yylocation_stack_.push (yyloc);
 
@@ -666,7 +726,13 @@ namespace yy {
 
   yyreturn:
     if (yychar != yyempty_)
-      yydestruct_ ("Cleanup: discarding lookahead", yytoken, &yylval, &yylloc);
+      {
+        /* Make sure we have latest lookahead translation.  See comments
+           at user semantic actions for why this is necessary.  */
+        yytoken = yytranslate_ (yychar);
+        yydestruct_ ("Cleanup: discarding lookahead", yytoken, &yylval,
+                     &yylloc);
+      }
 
     /* Do not reclaim the symbols of the rule which action triggered
        this YYABORT or YYACCEPT.  */
@@ -685,51 +751,97 @@ namespace yy {
 
   // Generate an error message.
   std::string
-  calcxx_parser::yysyntax_error_ (int yystate, int tok)
+  calcxx_parser::yysyntax_error_ (int yystate, int yytoken)
   {
-    std::string res;
-    YYUSE (yystate);
-#if YYERROR_VERBOSE
-    int yyn = yypact_[yystate];
-    if (yypact_ninf_ < yyn && yyn <= yylast_)
+    std::string yyres;
+    // Number of reported tokens (one for the "unexpected", one per
+    // "expected").
+    size_t yycount = 0;
+    // Its maximum.
+    enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
+    // Arguments of yyformat.
+    char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
+
+    /* There are many possibilities here to consider:
+       - If this state is a consistent state with a default action, then
+         the only way this function was invoked is if the default action
+         is an error action.  In that case, don't check for expected
+         tokens because there are none.
+       - The only way there can be no lookahead present (in yytoken) is
+         if this state is a consistent state with a default action.
+         Thus, detecting the absence of a lookahead is sufficient to
+         determine that there is no unexpected or expected token to
+         report.  In that case, just report a simple "syntax error".
+       - Don't assume there isn't a lookahead just because this state is
+         a consistent state with a default action.  There might have
+         been a previous inconsistent state, consistent state with a
+         non-default action, or user semantic action that manipulated
+         yychar.
+       - Of course, the expected token list depends on states to have
+         correct lookahead information, and it depends on the parser not
+         to perform extra reductions after fetching a lookahead from the
+         scanner and before detecting a syntax error.  Thus, state
+         merging (from LALR or IELR) and default reductions corrupt the
+         expected token list.  However, the list is correct for
+         canonical LR with one exception: it will still contain any
+         token that will not be accepted due to an error action in a
+         later state.
+    */
+    if (yytoken != yyempty_)
       {
-	/* Start YYX at -YYN if negative to avoid negative indexes in
-	   YYCHECK.  */
-	int yyxbegin = yyn < 0 ? -yyn : 0;
-
-	/* Stay within bounds of both yycheck and yytname.  */
-	int yychecklim = yylast_ - yyn + 1;
-	int yyxend = yychecklim < yyntokens_ ? yychecklim : yyntokens_;
-	int count = 0;
-	for (int x = yyxbegin; x < yyxend; ++x)
-	  if (yycheck_[x + yyn] == x && x != yyterror_)
-	    ++count;
-
-	// FIXME: This method of building the message is not compatible
-	// with internationalization.  It should work like yacc.c does it.
-	// That is, first build a string that looks like this:
-	// "syntax error, unexpected %s or %s or %s"
-	// Then, invoke YY_ on this string.
-	// Finally, use the string as a format to output
-	// yytname_[tok], etc.
-	// Until this gets fixed, this message appears in English only.
-	res = "syntax error, unexpected ";
-	res += yytnamerr_ (yytname_[tok]);
-	if (count < 5)
-	  {
-	    count = 0;
-	    for (int x = yyxbegin; x < yyxend; ++x)
-	      if (yycheck_[x + yyn] == x && x != yyterror_)
-		{
-		  res += (!count++) ? ", expecting " : " or ";
-		  res += yytnamerr_ (yytname_[x]);
-		}
-	  }
+        yyarg[yycount++] = yytname_[yytoken];
+        int yyn = yypact_[yystate];
+        if (!yy_pact_value_is_default_ (yyn))
+          {
+            /* Start YYX at -YYN if negative to avoid negative indexes in
+               YYCHECK.  In other words, skip the first -YYN actions for
+               this state because they are default actions.  */
+            int yyxbegin = yyn < 0 ? -yyn : 0;
+            /* Stay within bounds of both yycheck and yytname.  */
+            int yychecklim = yylast_ - yyn + 1;
+            int yyxend = yychecklim < yyntokens_ ? yychecklim : yyntokens_;
+            for (int yyx = yyxbegin; yyx < yyxend; ++yyx)
+              if (yycheck_[yyx + yyn] == yyx && yyx != yyterror_
+                  && !yy_table_value_is_error_ (yytable_[yyx + yyn]))
+                {
+                  if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
+                    {
+                      yycount = 1;
+                      break;
+                    }
+                  else
+                    yyarg[yycount++] = yytname_[yyx];
+                }
+          }
       }
-    else
-#endif
-      res = YY_("syntax error");
-    return res;
+
+    char const* yyformat = YY_NULL;
+    switch (yycount)
+      {
+#define YYCASE_(N, S)                         \
+        case N:                               \
+          yyformat = S;                       \
+        break
+        YYCASE_(0, YY_("syntax error"));
+        YYCASE_(1, YY_("syntax error, unexpected %s"));
+        YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
+        YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
+        YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
+        YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
+#undef YYCASE_
+      }
+
+    // Argument number.
+    size_t yyi = 0;
+    for (char const* yyp = yyformat; *yyp; ++yyp)
+      if (yyp[0] == '%' && yyp[1] == 's' && yyi < yycount)
+        {
+          yyres += yytnamerr_ (yyarg[yyi++]);
+          ++yyp;
+        }
+      else
+        yyres += *yyp;
+    return yyres;
   }
 
 
@@ -743,13 +855,13 @@ namespace yy {
        7,     7,     7,    -9,    -1,     6,     6,    -9,    -9
   };
 
-  /* YYDEFACT[S] -- default rule to reduce with in state S when YYTABLE
-     doesn't specify something else to do.  Zero means the default is an
-     error.  */
+  /* YYDEFACT[S] -- default reduction number in state S.  Performed when
+     YYTABLE doesn't specify something else to do.  Zero means the
+     default is an error.  */
   const unsigned char
   calcxx_parser::yydefact_[] =
   {
-         4,     0,     0,     1,    10,    11,     3,     2,     0,     0,
+         3,     0,     0,     1,    10,    11,     4,     2,     0,     0,
        0,     0,     0,    10,     5,     6,     7,     8,     9
   };
 
@@ -769,7 +881,7 @@ namespace yy {
 
   /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
      positive, shift that token.  If negative, reduce the rule which
-     number is the opposite.  If zero, do what YYDEFACT says.  */
+     number is the opposite.  If YYTABLE_NINF_, syntax error.  */
   const signed char calcxx_parser::yytable_ninf_ = -1;
   const unsigned char
   calcxx_parser::yytable_[] =
@@ -817,11 +929,11 @@ namespace yy {
   const unsigned char
   calcxx_parser::yyr2_[] =
   {
-         0,     2,     2,     2,     0,     3,     3,     3,     3,     3,
+         0,     2,     2,     0,     2,     3,     3,     3,     3,     3,
        1,     1
   };
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+
   /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
      First, the terminals, then, starting at \a yyntokens_, nonterminals.  */
   const char*
@@ -829,16 +941,15 @@ namespace yy {
   {
     "\"end of file\"", "error", "$undefined", "\":=\"", "\"identifier\"",
   "\"number\"", "'+'", "'-'", "'*'", "'/'", "$accept", "unit",
-  "assignments", "assignment", "exp", 0
+  "assignments", "assignment", "exp", YY_NULL
   };
-#endif
 
 #if YYDEBUG
   /* YYRHS -- A `-1'-separated list of the rules' RHS.  */
   const calcxx_parser::rhs_number_type
   calcxx_parser::yyrhs_[] =
   {
-        11,     0,    -1,    12,    14,    -1,    12,    13,    -1,    -1,
+        11,     0,    -1,    12,    14,    -1,    -1,    12,    13,    -1,
        4,     3,    14,    -1,    14,     6,    14,    -1,    14,     7,
       14,    -1,    14,     8,    14,    -1,    14,     9,    14,    -1,
        4,    -1,     5,    -1
@@ -849,7 +960,7 @@ namespace yy {
   const unsigned char
   calcxx_parser::yyprhs_[] =
   {
-         0,     0,     3,     6,     9,    10,    14,    18,    22,    26,
+         0,     0,     3,     6,     7,    10,    14,    18,    22,    26,
       30,    32
   };
 
@@ -857,8 +968,8 @@ namespace yy {
   const unsigned short int
   calcxx_parser::yyrline_[] =
   {
-         0,  8536,  8536,  8538,  8539,  8542,  8547,  8548,  8549,  8550,
-    8551,  8552
+         0,  9749,  9749,  9752,  9753,  9756,  9761,  9762,  9763,  9764,
+    9765,  9766
   };
 
   // Print the state stack on the debug stream.
@@ -947,14 +1058,13 @@ namespace yy {
 
 } // yy
 
-/* Line 1053 of lalr1.cc  */
-#line 952 "./calc++-parser.cc"
+/* Line 1108 of lalr1.cc  */
+#line 1063 "../../../../examples/calc++/calc++-parser.cc"
 
+/* Line 1109 of lalr1.cc  */
+#line 9767 "../../doc/bison.texi"
 
-/* Line 1055 of lalr1.cc  */
-#line 8553 "../../doc/bison.texinfo"
-
-#line 8562 "../../doc/bison.texinfo"
+#line 9776 "../../doc/bison.texi"
 void
 yy::calcxx_parser::error (const yy::calcxx_parser::location_type& l,
                           const std::string& m)
